@@ -199,9 +199,20 @@ def readTableColumnGeo(table,name):
     settings.beginGroup(name)
     ei = table.property("ExtensionId")
     table.setProperty("ExtensionId", None)
+    total = sum([table.columnWidth(i) for i in range(table.model().columnCount(None))])
+    defaults = None
+    defaultTotal = None
+    if hasattr(table.model(), "columnWidthRatios"):
+        defaults = table.model().columnWidthRatios()
+        defaults = [defaults[i] for i in range(table.model().columnCount(None))]
+        if None not in defaults:
+            defaultTotal = sum(defaults)
     for i in range(table.model().columnCount(None)):
         if settings.value("Column%02i"%i,-1) != -1:
             table.setColumnWidth(i,int(settings.value("Column%02i"%i,-1)))
+        else:
+            if defaults is not None and defaults[i] is not None:
+                table.setColumnWidth(i, int(float(defaults[i]) * total / defaultTotal))
     table.setProperty("ExtensionId", ei)
     settings.endGroup()
 
@@ -223,9 +234,16 @@ class TabMenuHolder:
         self.actSaveThis = QtGui.QAction("&Reopen to current tab", self.tab)
         self.actSaveThis.setCheckable(True)
 
-        self.tab.setContextMenuPolicy(QtCore.Qt.ActionsContextMenu)
-        self.tab.addAction(self.actSaveLast)
-        self.tab.addAction(self.actSaveThis)
+        self.tab.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
+        self.tab.customContextMenuRequested.connect(self.contextMenu)
+
+    def contextMenu(self, pnt):
+        tb = self.tab.tabBar()
+        if tb.tabAt(pnt) == self.tab.currentIndex():
+            self.menu = QtGui.QMenu()
+            self.menu.addAction(self.actSaveLast)
+            self.menu.addAction(self.actSaveThis)
+            self.menu.popup(self.tab.mapToGlobal(pnt))
 
     def setChecks(self, status):
         self.actSaveLast.setChecked(status == WindowGeometry.TAB_REOPEN_LAST)
@@ -480,6 +498,37 @@ class OnlineHelp(QtCore.QObject):
         xplatform.xdg_open(anchored)
 
 
+def message_excepthook(type, value, tb):
+    """
+    Replace sys.excepthook with this function to display errors more gracefully 
+    for an application which is not associated with a console.
+    
+    Refer to qtalchemy.xplatform.guiexcepthook for a lighter weight version of this.
+    
+    >>> import sys
+    >>> from qtalchemy import *
+    >>> sys.excepthook = message_excepthook
+    """
+    try:
+        import traceback
+
+        msgBox = QtGui.QMessageBox()
+        msgBox.setWindowTitle(QtGui.QApplication.applicationName())
+        msgBox.setIcon(QtGui.QMessageBox.Critical)
+        
+        tb2 = "An unhandled error was encountered.  Consider copying this entire message to an email to the program author by pressing Ctrl+C on this message.  Include a brief description of the actions leading to this error.\n\n{0}" \
+                    .format(''.join(traceback.format_exception(type, value, tb, limit=None)))
+        
+        msgBox.setText( tb2 )
+        
+        msgBox.setStandardButtons(QtGui.QMessageBox.Ok)
+        msgBox.exec_()
+    except:
+        #raise
+        import sys
+        traceback.print_exception(type, value, tb, limit=None, file=sys.stderr)
+
+
 _test_app = None
 
 def qtapp():
