@@ -326,6 +326,16 @@ def attrType(cls, col):
 
     return ClassAttributeType(getattr(cls,col))
 
+def attrWidth(cls, col):
+    """
+    Returns the width of a ModelColumn or SA column.
+    """
+    try:
+        return col.width
+    except AttributeError:
+        pass
+    return None
+
 def attrReadonly(cls, col):
     try:
         return col.readonly
@@ -405,7 +415,13 @@ def AttrWidgetFactory(userattr,parent=None, index=None):
 
 
 class ModelColumn:
-    def __init__(self,attr,type_,label=None,readonly=False):
+    def __init__(self, attr, type_, label=None, readonly=False, width=None):
+        """
+        :param attr:  attribute name
+        :param label:  label to display in the list header
+        :param readonly:  true if the column should not be editable even if the view is
+        :param width:  width in pixels (?) or relative width to other columns
+        """
         self.attr = attr
         if label is None:
             self.label = attr.title().replace("_"," ")
@@ -413,6 +429,7 @@ class ModelColumn:
             self.label = label
         self.type_ = type_
         self.readonly = readonly
+        self.width = width
 
 
 class ObjectRepresent(object):
@@ -832,8 +849,11 @@ class PBTableModel(QtCore.QAbstractItemModel):
             self.endRemoveRows()
             return True
 
+    def columnWidthRatios(self):
+        return dict([(i, self.columns[i].width) for i in range(len(self.columns))])
+    
     def headerData(self, col, orientation, role):
-        if ( orientation == QtCore.Qt.Horizontal and role == QtCore.Qt.DisplayRole ):
+        if orientation == QtCore.Qt.Horizontal and role == QtCore.Qt.DisplayRole:
             return attrLabel(self.cls, self.columns[col])
         return None
 
@@ -903,11 +923,19 @@ class PBTableModel(QtCore.QAbstractItemModel):
         #  The None/"" dichotomy is a frightening mess -- we need to think carefully about all that.
         if oldValue is None:
             oldValue = toQType(oldValue, attrType(self.cls, c))
+
+        result = True
         if newValue != oldValue:
             self.ensureNoFlipper(index)
 
-            setattr(r, c.attr if hasattr(c, "attr") else c, newValue)
-        return True
+            try:
+                setattr(r, c.attr if hasattr(c, "attr") else c, newValue)
+            except:
+                # TODO:  Consider high-lighting the table cell which failed
+                # however, we believe this should be in the view, not the model
+                # Note:  We expect a dialog listen on the session message event for session validation messages.
+                result = False
+        return result
 
     def flags(self,index):
         result = QtCore.Qt.ItemIsSelectable | QtCore.Qt.ItemIsEnabled
