@@ -16,7 +16,7 @@ sqlalchemy and PyQt/PySide.
 from PyQtHelpers import LayoutWidget, LayoutLayout, ButtonBoxButton, FormRow, \
             WindowGeometry, OnlineHelp, \
             writeTableColumnGeo, readTableColumnGeo, suffixExtId, \
-            fromQType, toQType, qtapp, \
+            fromQType, toQType, qtapp, message_excepthook, \
             Signal, Slot, Property
 
 from commands import DomainEntity, Command, CommandMenu, CommandEvent, \
@@ -27,8 +27,10 @@ from sqlalchemy_helper import ModelObject, ModelSession, PBSessionMaker, UUID, \
         ValidationError, user_message, Message, instanceEvent, sessionExtension
 
 from input_yoke import \
+    addGlobalYoke, \
     InputYoke, \
     LineYoke, \
+    SelectionYoke, \
     TextYoke, \
     IntegerYoke, \
     DateYoke, \
