@@ -98,7 +98,10 @@ class LineYoke(InputYoke):
         if isinstance(self.widget, QtGui.QLineEdit):
             self.widget.setText(self.mapper.getObjectAttr(self.attr))
         elif isinstance(self.widget, QtGui.QComboBox):
-            self.widget.setEditText(self.mapper.getObjectAttr(self.attr))
+            if self.widget.isEditable():
+                self.widget.setEditText(self.mapper.getObjectAttr(self.attr))
+            else:
+                self.widget.setCurrentIndex(self.widget.findText(self.mapper.getObjectAttr(self.attr), QtCore.Qt.MatchFixedString))
         else:
             raise ValueError("The widget {0} is not supported by a {1}".format(self.widget, self.__class__.__name__))
 
@@ -112,6 +115,43 @@ class LineYoke(InputYoke):
         else:
             raise ValueError("The widget {0} is not supported by a {1}".format(self.widget, self.__class__.__name__))
 
+class SelectionYoke(LineYoke):
+    """
+    This yoke drives combo boxes.  Note that this yoke is not directly 
+    usable as a yoke factory due to the options parameter.  It is intended 
+    to be wrapped in a factory function and exposed to the global yoke 
+    factory with :func:`addGlobalYoke`.
+    
+    >>> def ColorComboYoke(mapper, attr):
+    ...     return SelectionYoke(mapper, attr, ["Red", "Orange", "Yellow", "Green", "Blue", "Indigo", "Violet"])
+    ...
+    >>> addGlobalYoke('color', ColorComboYoke)
+    
+    :param options:  a list of strings to include in the combo box
+    """
+    def __init__(self, mapper, attr, options):
+        LineYoke.__init__(self, mapper, attr)
+        self.options = options
+
+    def Factory(self):
+        self.widget = QtGui.QComboBox()
+        self._baseAdoptWidget(self.widget)
+        self._loadOptions()
+        if attrReadonly(self.mapper.cls, self.attr):
+            self.widget.setReadOnly(True)
+        return self.widget
+
+    def AdoptWidget(self, widget):
+        self.widget = widget
+        self._baseAdoptWidget(self.widget)
+        self._loadOptions()
+        if hasattr(self.widget, "setReadOnly") and attrReadonly(self.mapper.cls, self.attr):
+            self.widget.setReadOnly(True)
+
+    def _loadOptions(self):
+        for o in self.options:
+            self.widget.addItem(o)
+
 class PasswordYoke(LineYoke):
     def Factory(self):
         LineYoke.Factory(self)
@@ -371,7 +411,10 @@ class BooleanRadioYoke(InputYoke):
         self.false_radio = widget[1]
         
         if self.true_radio.group() is None:
-            self.group = QtGui.QButtonGroup(self.true_radio)
+            # it's unclear what an appropriate parent widget would be for the QButtonGroup
+            # does it need one?
+            # I think that using self.true_radio gets Qt in a minor funk because it might be a parent loop (It gets PySide in a funk for sure)
+            self.group = QtGui.QButtonGroup(self.true_radio.parent())
             self.group.addButton(self.true_radio)
             self.group.addButton(self.false_radio)
 
@@ -431,7 +474,41 @@ def yokes_dict():
 
     return d
 
+def addGlobalYoke(yoke, yokeFactory):
+    """
+    Add the yoke and yokeFactory to the global list of yokes.  Currently this 
+    relies on the singleton QtCore.QCoreApplication.instance() by adding the 
+    yoke to a dictionary set up in the yokes attribute of this class.  This 
+    implementation detail has user ramifications, but is not considered an 
+    ideal implementation.
+    
+    :param yoke:  the name of the yoke
+    :param yokeFactory:  a callable taking a mapper class and an attribute
+    """
+    if not QtCore.QCoreApplication.instance():
+        raise RuntimeError("The addGlobalYoke function relies on having a QtCore.QCoreApplication instance available")
+    
+    if not hasattr(QtCore.QCoreApplication.instance(),"yokes"):
+        QtCore.QCoreApplication.instance().yokes = {}
+
+    QtCore.QCoreApplication.instance().yokes[yoke] = yokeFactory
+
 def YokeFactory(cls, attr, mapper, parent=None, index=None):
+    """
+    Create a yoke for the attribute `attr` in class `cls`.  Each sqlalchemy 
+    column attribute and UserAttr can have a yoke specified for it in the 
+    following ways:
+      - specify a named yoke in a sqlalchemy column by including an info 
+        parameter to the Column constructor.  For example::
+        
+            Column('name', Text, info={"yoke": "line"})
+
+      - specify a named yoke in a UserAttr derived class by overriding the 
+        yoke_specifier method and returning the name of the yoke
+
+    The list of yoke names is extensible and individual yokes can be replaced by 
+    calling :func:`addGlobalYoke`.
+    """
     userattr = getattr(cls,attr)
     spec = ClassAttributeYoke(userattr)
     yoke_class = yokes_dict()[spec]
