@@ -118,20 +118,17 @@ class UserAttr(property):
     """
     The UserAttr type provides python object attribute type validation.
     
-    TODO:  Adopt python properties or provide a coherent illustration 
-    illustrating why the on_get/on_change model of UserAttr is better.  We 
-    believe that the UserAttr model is better in the sense of being higher-
-    level.  Interlocking getters and setters in python properties would 
-    require user instrumentation code to deal with recursion and change 
-    notifications.  This instrumentation is incomplete in the current UserAttr 
-    implementation, but the belief is that we can add the instrumentation 
-    with-in this interface more gracefully.
-    
-    TODO:  Consider how to extend the on_get/on_change model to include 
-    sqlalchemy column attributes.
+    The UserAttr class is designed to be used in conjunction with
+    :class:`qtalchemy.ModelObject`.  
+
+    Currently the on_get event semantics is inconsistent with the use of the
+    ModelObject.Events event model.  That is the UserAttr.on_get decorator is
+    on the attribute itself, but the ModelObject.Events.add operator is based
+    on an instance of ModelObject.Events.  The advantage of the latter is that
+    it works consistently for both UserAttr and sqlalchemy column objects.
 
     EXAMPLE::
-        >>> class Person(object):
+        >>> class Person(ModelObject):
         ...     name = UserAttr(str,"Person Name")
         ...     age = UserAttr(int,"Age")
         ...     married = UserAttr(bool,"Married")
