@@ -26,7 +26,10 @@ class DateValidator(QtGui.QValidator):
     def fixup(self,input):
         if input == "":
             return ""
-        date = fuzzyparsers.parse_date(input)
+        try:
+            date = fuzzyparsers.parse_date(input)
+        except:
+            return ""
         #input.replace(0,input.length(),date.strftime("%x"))
         print date.strftime("%x")
         return date.strftime("%x")
