@@ -7,15 +7,16 @@
 ##############################################################################
 
 from PyQt4 import QtCore, QtGui
-from qtalchemy import fromQType,  writeTableColumnGeo, readTableColumnGeo
+from qtalchemy import fromQType, modelMimeRectangle, writeTableColumnGeo, readTableColumnGeo
+from viewbase import ViewBase
 
-class TableView(QtGui.QTableView):
+class TableView(QtGui.QTableView, ViewBase):
     """
     The TableView provides a QTableView override with support for the following elements:
 
     - row deletion with ctrl+delete for editable models
     - tab skipping read-only columns for editable models
-    - clipboard copy of the selected blocks (actually an enclosing rectangle of the selection)
+    - clipboard copy of the selected blocks
     - load & save column geometry from user settings
 
     :param parent:  Qt parent widget for this table
@@ -42,8 +43,8 @@ class TableView(QtGui.QTableView):
 
         # hook up header events to save section widths
         header = self.horizontalHeader()
-        header.sectionResized.connect(self.saveSections)
-        header.sectionAutoResize.connect(self.saveSections2)
+        header.sectionResized.connect(lambda x,y,z: self.saveSections())
+        header.sectionAutoResize.connect(lambda x,y: self.saveSections())
 
     def setModel(self, model, extensionId=None):
         """
@@ -61,59 +62,16 @@ class TableView(QtGui.QTableView):
         if self.property("ExtensionId") is not None:
             readTableColumnGeo(self, self.property("ExtensionId"))
 
-    def delKeyPressed(self):
-        #print "deleting"
-        model = self.model()
-        index = self.currentIndex()
-        
-        # We'll just call removeRows.  If the model doesn't support it, it returns False
-        model.removeRows(index.row(),1,index.parent())
-
     def keyPressEvent(self, event):
         """
-        * Copy key should copy selection 
+        Copy key copies selection 
         """
         if event.matches(QtGui.QKeySequence.Copy):
-            # We copy out the smallest rectangular array encompassing the selected indexes.
-            model = self.model()
-            selected = self.selectedIndexes()
-            if len(selected):
-                parent = selected[0].parent()
-                max_row = min_row = selected[0].row()
-                max_column = min_column = selected[0].column()
-                for i in selected:
-                    if i.row() > max_row: max_row = i.row()
-                    if i.row() < min_row: min_row = i.row()
-                    if i.column() > max_column: max_column = i.column()
-                    if i.column() < min_column: min_column = i.column()
-                rows = ['\t'.join([model.headerData(x,QtCore.Qt.Horizontal,QtCore.Qt.DisplayRole) for x in range(min_column,max_column+1)])]
-                for y in range(min_row,max_row+1):
-                    rows.append('\t'.join([str(fromQType(model.data(model.createIndex(y,x,parent),QtCore.Qt.DisplayRole))) for x in range(min_column,max_column+1)]))
-                cb = QtGui.QApplication.instance().clipboard()
-                m = QtCore.QMimeData()
-                m.setData("text/plain",'\n'.join(rows))
-                cb.setMimeData(m)
+            cb = QtGui.QApplication.instance().clipboard()
+            cb.setMimeData(modelMimeRectangle(self.model(), self.selectedIndexes()))
         else:
             QtGui.QTableView.keyPressEvent(self,event)
 
-    def nextIndex(self,index):
-        model = self.model()
-        if index.column()+1 < model.columnCount(index.parent()):
-            return model.createIndex(index.row(),index.column()+1,index.parent())
-        elif index.row()+1 < model.rowCount(index.parent()):
-            return model.createIndex(index.row()+1,0,index.parent())
-        else:
-            return model.createIndex(0,0,index.parent())
-
-    def prevIndex(self,index):
-        model = self.model()
-        if index.column() > 0:
-            return model.createIndex(index.row(),index.column()-1,index.parent())
-        elif index.row() > 0:
-            return model.createIndex(index.row()-1,model.columnCount(index.parent())-1,index.parent())
-        else:
-            return model.createIndex(index.rowCount(index.parent())-1,model.columnCount(index.parent())-1,index.parent())
-
     def edit(self, index, trigger, event):
         # At this point this method is overridden strictly as a place to set the flag to initiate the 
         # semantics of moveCursor to skip read-only cells in tabbing.
@@ -132,7 +90,7 @@ class TableView(QtGui.QTableView):
             if cursorAction == QtGui.QAbstractItemView.MoveNext:
                 index = self.currentIndex()
                 model = self.model()
-                while True and iterations < cell_max:
+                while iterations < cell_max:
                     iterations += 1
                     candidate = self.nextIndex(index)
                     if (model.flags(candidate) & QtCore.Qt.ItemIsEditable) == QtCore.Qt.ItemIsEditable:
@@ -141,7 +99,8 @@ class TableView(QtGui.QTableView):
             elif cursorAction == QtGui.QAbstractItemView.MovePrevious:
                 index = self.currentIndex()
                 model = self.model()
-                while True and iterations < cell_max:
+                while iterations < cell_max:
+                    print iterations
                     iterations += 1
                     candidate = self.prevIndex(index)
                     if (model.flags(candidate) & QtCore.Qt.ItemIsEditable) == QtCore.Qt.ItemIsEditable:
@@ -149,14 +108,6 @@ class TableView(QtGui.QTableView):
                     index = candidate
         return QtGui.QTableView.moveCursor(self,cursorAction,modifiers)
 
-    def saveSections(self, logicalIndex, oldSize, newSize):
-        if self.property("ExtensionId") is not None:
-            writeTableColumnGeo(self, self.property("ExtensionId"))
-
-    def saveSections2(self, logicalIndex, mode):
-        if self.property("ExtensionId") is not None:
-            writeTableColumnGeo(self, self.property("ExtensionId"))
-
     def preReset(self):
         index = self.selectionModel().currentIndex()
         if index is not None and index.isValid():
